@@ -4,40 +4,13 @@ use YAML::Base;
 use base 'YAML::Base';
 use YAML::Node;         # XXX This is a temp fix for Module::Build
 use 5.006001;
-our $VERSION = '0.58';
+our $VERSION = '0.68';
 our @EXPORT = qw'Dump Load';
 our @EXPORT_OK = qw'freeze thaw DumpFile LoadFile Bless Blessed';
 
 # XXX This VALUE nonsense needs to go.
 use constant VALUE => "\x07YAML\x07VALUE\x07";
 
-# Global Options are an idea taken from Data::Dumper. Really they are just
-# sugar on top of real OO properties. They make the simple Dump/Load API
-# easy to configure.
-#
-# These options are no longer set by YAML.pm into globals. The action
-# modules will check the globals, set by the user.
-
-# New global options
-# our $SpecVersion = '1.0';
-# our $LoaderClass = '';
-# our $DumperClass = '';
-
-# Legacy global options
-# our $Indent         = 2;
-# our $UseHeader      = 1;
-# our $UseVersion     = 0;
-# our $SortKeys       = 1;
-# our $AnchorPrefix   = '';
-# our $UseCode        = 0;
-# our $DumpCode       = '';
-# our $LoadCode       = '';
-# our $UseBlock       = 0;
-# our $UseFold        = 0;
-# our $CompressSeries = 1;
-# our $UseAliases     = 1;
-# our $Stringify      = 0;
-
 # YAML Object Properties
 field dumper_class => 'YAML::Dumper';
 field loader_class => 'YAML::Loader';
@@ -69,23 +42,35 @@ sub Load {
 }
 
 sub DumpFile {
+    my $OUT;
     my $filename = shift;
-    local $/ = "\n"; # reset special to "sane"
-    my $mode = '>';
-    if ($filename =~ /^\s*(>{1,2})\s*(.*)$/) {
-        ($mode, $filename) = ($1, $2);
+    if (ref $filename eq 'GLOB') {
+        $OUT = $filename;
     }
-    open my $OUT, $mode, $filename
-      or YAML::Base->die('YAML_DUMP_ERR_FILE_OUTPUT', $filename, $!);
+    else {
+        my $mode = '>';
+        if ($filename =~ /^\s*(>{1,2})\s*(.*)$/) {
+            ($mode, $filename) = ($1, $2);
+        }
+        open $OUT, $mode, $filename
+          or YAML::Base->die('YAML_DUMP_ERR_FILE_OUTPUT', $filename, $!);
+    }  
+    local $/ = "\n"; # reset special to "sane"
     print $OUT Dump(@_);
 }
 
 sub LoadFile {
+    my $IN;
     my $filename = shift;
-    open my $IN, $filename
-      or YAML::Base->die('YAML_LOAD_ERR_FILE_INPUT', $filename, $!);
+    if (ref $filename eq 'GLOB') {
+        $IN = $filename;
+    }
+    else {
+        open $IN, $filename
+          or YAML::Base->die('YAML_LOAD_ERR_FILE_INPUT', $filename, $!);
+    }
     return Load(do { local $/; <$IN> });
-}   
+}
 
 sub init_action_object {
     my $self = shift;
@@ -114,10 +99,32 @@ sub global_object { $global }
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 YAML - YAML Ain't Markup Language (tm)
 
+=head1 NOTE
+
+This module has been released to CPAN as YAML::Old, and soon YAML.pm
+will be changed to just be a frontend interface module for all the
+various Perl YAML implementation modules, including YAML::Old.
+
+If you want robust and fast YAML processing using the normal Dump/Load
+API, please consider switching to YAML::XS. It is by far the best Perl
+module for YAML at this time. It requires that you have a C compiler,
+since it is written in C.
+
+If you really need to use this version of YAML.pm it will always be
+available as YAML::Old.
+
+If you don't care which YAML module use, as long as it's the best one
+installed on your system, use YAML::Any.
+
+The rest of this documentation is left unchanged, until YAML.pm is
+switched over to the new UI-only version.
+
 =head1 SYNOPSIS
 
     use YAML;
@@ -791,8 +798,9 @@ have added help along the way.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, 2006. Ingy döt Net. All rights reserved.
-Copyright (c) 2001, 2002, 2005. Brian Ingerson. All rights reserved.
+Copyright (c) 2005, 2006, 2008. Ingy döt Net.
+
+Copyright (c) 2001, 2002, 2005. Brian Ingerson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
